@@ -114,13 +114,13 @@
 #'
 #' # vertical line at zero (with some optional styling)
 #' p + vline_0()
-#' p + vline_0(size = 0.25, color = "darkgray", linetype = 2)
+#' p + vline_0(linewidth = 0.25, color = "darkgray", linetype = 2)
 #'
 #' # vertical line(s) at specified values
 #' v <- c(-0.5, 0, 0.5)
-#' p + vline_at(v, linetype = 3, size = 0.25)
+#' p + vline_at(v, linetype = 3, linewidth = 0.25)
 #'
-#' my_lines <- vline_at(v, alpha = 0.25, size = 0.75 * c(1, 2, 1),
+#' my_lines <- vline_at(v, alpha = 0.25, linewidth = 0.75 * c(1, 2, 1),
 #'                      color = c("maroon", "skyblue", "violet"))
 #' p + my_lines
 #'
@@ -131,10 +131,10 @@
 #' p <- mcmc_intervals(x, regex_pars = "beta")
 #' p + vline_at(x[, 3:4], colMeans)
 #' p + vline_at(x[, 3:4], "colMeans", color = "darkgray",
-#'              lty = 2, size = 0.25)
+#'              lty = 2, linewidth = 0.25)
 #' p + vline_at(x[, 3:4], function(a) apply(a, 2, mean),
 #'              color = "orange",
-#'              size = 2, alpha = 0.1)
+#'              linewidth = 2, alpha = 0.1)
 #' }
 #'
 #' # using the lbub function to get interval lower and upper bounds (lb, ub)
@@ -146,9 +146,9 @@
 #'
 #' b1 <- x[, "beta[1]"]
 #' p2 + vline_at(b1, fun = lbub(0.8), color = "gray20",
-#'               size = 2 * c(1,.5,1), alpha = 0.75)
+#'               linewidth = 2 * c(1,.5,1), alpha = 0.75)
 #' p2 + vline_at(b1, lbub(0.8, med = FALSE), color = "gray20",
-#'               size = 2, alpha = 0.75)
+#'               linewidth = 2, alpha = 0.75)
 #'
 #'
 #' ##########################
@@ -185,7 +185,7 @@
 #'  myfacets +
 #'  yaxis_text(FALSE) +
 #'  yaxis_ticks(FALSE) +
-#'  xaxis_ticks(size = 1, color = "skyblue")
+#'  xaxis_ticks(linewidth = 1, color = "skyblue")
 #' }
 #'
 #' ##############################
@@ -209,7 +209,7 @@
 #'  legend_text(size = 14) +
 #'  legend_move(c(0.75, 0.5)) +
 #'  plot_bg(fill = "gray90") +
-#'  panel_bg(color = "black", fill = "gray99", size = 3)
+#'  panel_bg(color = "black", fill = "gray99", linewidth = 3)
 #' }
 #'
 #'
@@ -225,12 +225,14 @@
 #'     fun = dnorm,
 #'     args = list(mean(x[,, "beta[1]"]), sd(x[,, "beta[1]"])),
 #'     color = "purple",
-#'     size = 2
+#'     linewidth = 2
 #'   )
 #'
 #' color_scheme_set("gray")
-#' mcmc_hist(x, pars = "beta[1]") + purple_gaussian
-#' \donttest{mcmc_dens(x, pars = "beta[1]") + purple_gaussian}
+#' mcmc_hist(x, pars = "beta[1]", freq = FALSE) + purple_gaussian
+#' \donttest{
+#' mcmc_dens(x, pars = "beta[1]") + purple_gaussian
+#' }
 #'
 NULL
 
@@ -301,14 +303,16 @@ lbub <- function(p, med = TRUE) {
 
 # internal
 calc_v <- function(v, fun, fun_args, ...) {
-  if (missing(v))
+  if (missing(v)) {
     abort("'v' can't be missing.")
-  if (missing(fun))
+  }
+  if (missing(fun)) {
     return(v)
+  }
   f <- match.fun(fun)
-  if (missing(fun_args))
+  if (missing(fun_args)) {
     return(f(v))
-
+  }
   do.call(f, c(list(v), fun_args))
 }
 
@@ -329,7 +333,11 @@ calc_intervals <- function(x, p, med = TRUE, ...) {
 #'   equivalent to using `legend_none()`.
 #'
 legend_move <- function(position = "right") {
-  theme(legend.position = position)
+  if (is.numeric(position) && "legend.position.inside" %in% fn_fmls_names(theme)) {
+    theme(legend.position = "inside", legend.position.inside = position)
+  } else {
+    theme(legend.position = position)
+  }
 }
 #' @rdname bayesplot-helpers
 #' @export
@@ -347,8 +355,9 @@ legend_text <- function(...) {
 #' @rdname bayesplot-helpers
 #' @export
 xaxis_title <- function(on = TRUE, ...) {
-  if (!on)
+  if (!on) {
     return(xlab(NULL))
+  }
   theme(axis.title.x = element_text(...))
 }
 #' @rdname bayesplot-helpers
@@ -441,15 +450,15 @@ plot_bg <- function(on = TRUE, ...) {
 #'
 grid_lines <- function(color = "gray50", size = 0.2) {
   theme(
-    panel.grid.major = element_line(color = color, size = size),
-    panel.grid.minor = element_line(color = color, size = size * 0.5)
+    panel.grid.major = element_line(color = color, linewidth = size),
+    panel.grid.minor = element_line(color = color, linewidth = size * 0.5)
   )
 }
 
 grid_lines_y <- function(color = "gray50", size = 0.2) {
   theme(
-    panel.grid.major.y = element_line(color = color, size = size),
-    panel.grid.minor.y = element_line(color = color, size = size * 0.5)
+    panel.grid.major.y = element_line(color = color, linewidth = size),
+    panel.grid.minor.y = element_line(color = color, linewidth = size * 0.5)
   )
 }
 
