@@ -1,89 +1,81 @@
 #' Diagnostic plots for the No-U-Turn-Sampler (NUTS)
 #'
 #' Diagnostic plots for the No-U-Turn-Sampler (NUTS), the default MCMC algorithm
-#' used by Stan. See the \strong{Plot Descriptions} section, below.
+#' used by [Stan](https://mc-stan.org). See the **Plot Descriptions** section,
+#' below.
 #'
 #' @name MCMC-nuts
 #' @aliases NUTS
 #' @family MCMC
 #'
 #' @param x A molten data frame of NUTS sampler parameters, either created by
-#'   \code{\link{nuts_params}} or in the same form as the object returned by
-#'   \code{\link{nuts_params}}.
+#'   [nuts_params()] or in the same form as the object returned by
+#'   [nuts_params()].
 #' @param lp A molten data frame of draws of the log-posterior or, more
 #'   commonly, of a quantity equal to the log-posterior up to a constant.
-#'   \code{lp} should either be created via \code{\link{log_posterior}} or be an
+#'   `lp` should either be created via [log_posterior()] or be an
 #'   object with the same form as the object returned by
-#'   \code{\link{log_posterior}}.
+#'   [log_posterior()].
 #' @param chain A positive integer for selecting a particular chain. The default
-#'   (\code{NULL}) is to merge the chains before plotting. If \code{chain = k}
-#'   then the plot for chain \code{k} is overlaid (in a darker shade but with
-#'   transparency) on top of the plot for all chains. The \code{chain} argument
-#'   is not used by \code{mcmc_nuts_energy}.
+#'   (`NULL`) is to merge the chains before plotting. If `chain = k`
+#'   then the plot for chain `k` is overlaid (in a darker shade but with
+#'   transparency) on top of the plot for all chains. The `chain` argument
+#'   is not used by `mcmc_nuts_energy()`.
 #' @param ... Currently ignored.
 #'
 #' @return A gtable object (the result of calling
-#'   \code{\link[gridExtra]{arrangeGrob}}) created from several ggplot objects,
-#'   except for \code{mcmc_nuts_energy}, which returns a ggplot object.
+#'   [gridExtra::arrangeGrob()]) created from several ggplot objects,
+#'   except for `mcmc_nuts_energy()`, which returns a ggplot object.
 #'
 #' @section Quick Definitions:
 #' For more details see Stan Development Team (2016) and Betancourt (2017).
-#' \itemize{
-#'   \item \code{accept_stat__}: the average acceptance probabilities of all
+#' * `accept_stat__`: the average acceptance probabilities of all
 #'   possible samples in the proposed tree.
-#'   \item \code{divergent__}: the number of leapfrog transitions with diverging
+#' * `divergent__`: the number of leapfrog transitions with diverging
 #'   error. Because NUTS terminates at the first divergence this will be either
 #'   0 or 1 for each iteration.
-#'   \item \code{stepsize__}: the step size used by NUTS in its Hamiltonian
+#' * `stepsize__`: the step size used by NUTS in its Hamiltonian
 #'   simulation.
-#'   \item \code{treedepth__}: the depth of tree used by NUTS, which is the log
+#' * `treedepth__`: the depth of tree used by NUTS, which is the log
 #'   (base 2) of the number of leapfrog steps taken during the Hamiltonian
 #'   simulation.
-#'   \item \code{energy__}: the value of the Hamiltonian (up to an additive
+#' * `energy__`: the value of the Hamiltonian (up to an additive
 #'   constant) at each iteration.
-#' }
 #'
 #' @section Plot Descriptions:
 #' \describe{
-#'   \item{\code{mcmc_nuts_acceptance}}{
+#'   \item{`mcmc_nuts_acceptance()`}{
 #'   Three plots:
-#'   \itemize{
-#'    \item Histogram of \code{accept_stat__} with vertical lines indicating the
-#'    mean (solid line) and median (dashed line).
-#'    \item Histogram of \code{lp__} with vertical
-#'    lines indicating the mean (solid line) and median (dashed line).
-#'    \item Scatterplot of \code{accept_stat__} vs \code{lp__}.
-#'    }
+#'   * Histogram of `accept_stat__` with vertical lines indicating the
+#'     mean (solid line) and median (dashed line).
+#'   * Histogram of `lp__` with vertical
+#'     lines indicating the mean (solid line) and median (dashed line).
+#'   * Scatterplot of `accept_stat__` vs `lp__`.
 #'   }
-#'   \item{\code{mcmc_nuts_divergence}}{
+#'
+#'   \item{`mcmc_nuts_divergence()`}{
 #'   Two plots:
-#'   \itemize{
-#'    \item Violin plots of \code{lp__|divergent__=1} and
-#'      \code{lp__|divergent__=0}.
-#'    \item Violin plots of \code{accept_stat__|divergent__=1} and
-#'      \code{accept_stat__|divergent__=0}.
-#'    }
+#'   * Violin plots of `lp__|divergent__=1` and `lp__|divergent__=0`.
+#'   * Violin plots of `accept_stat__|divergent__=1` and
+#'     `accept_stat__|divergent__=0`.
 #'   }
-#'   \item{\code{mcmc_nuts_stepsize}}{
+#'
+#'   \item{`mcmc_nuts_stepsize()`}{
 #'   Two plots:
-#'   \itemize{
-#'    \item Violin plots of \code{lp__} by chain ordered by
-#'    \code{stepsize__} value.
-#'    \item Violin plots of \code{accept_stat__} by chain ordered by
-#'    \code{stepsize__} value.
-#'    }
+#'   * Violin plots of `lp__` by chain ordered by `stepsize__` value.
+#'   * Violin plots of `accept_stat__` by chain ordered by `stepsize__` value.
 #'   }
-#'   \item{\code{mcmc_nuts_treedepth}}{
+#'
+#'   \item{`mcmc_nuts_treedepth()`}{
 #'   Three plots:
-#'   \itemize{
-#'    \item Violin plots of \code{lp__} by value of \code{treedepth__}.
-#'    \item Violin plots of \code{accept_stat__} by value of \code{treedepth__}.
-#'    \item Histogram of \code{treedepth__}.
-#'    }
+#'   * Violin plots of `lp__` by value of `treedepth__`.
+#'   * Violin plots of `accept_stat__` by value of `treedepth__`.
+#'   * Histogram of `treedepth__`.
 #'   }
-#'   \item{\code{mcmc_nuts_energy}}{
-#'   Overlaid histograms showing \code{energy__} vs the change in
-#'   \code{energy__}. See Betancourt (2016) for details.
+#'
+#'   \item{`mcmc_nuts_energy()`}{
+#'   Overlaid histograms showing `energy__` vs the change in
+#'   `energy__`. See Betancourt (2016) for details.
 #'   }
 #' }
 #'
@@ -92,28 +84,24 @@
 #' @template reference-stan-manual
 #'
 #' @seealso
-#' \itemize{
-#' \item The \emph{Visual MCMC Diagnostics} vignette.
-#' \item Several other plotting functions in the \pkg{bayesplot} package
-#' are not NUTS-specific but take optional extra arguments if the model was fit
-#' using NUTS:
-#' \itemize{
-#'  \item \code{\link{mcmc_trace}}: show divergences as tick marks below the
-#'  trace plot.
-#'  \item \code{\link{mcmc_parcoord}}: change the color/size/transparency of
-#'  lines correspondending to divergences.
-#'  \item \code{\link{mcmc_scatter}}: change the color/size/shape of points
-#'  corresponding to divergences.
-#'  \item \code{\link{mcmc_pairs}}: change the color/size/shape of points
-#'  corresponding divergences and/or max treedepth saturation.
-#'  }
-#' }
+#' * The [Visual MCMC Diagnostics](https://mc-stan.org/bayesplot/articles/visual-mcmc-diagnostics.html)
+#'   vignette.
+#' * Several other plotting functions are not NUTS-specific but take optional
+#'   extra arguments if the model was fit using NUTS:
+#'   * [mcmc_trace()]: show divergences as tick marks below the
+#'     trace plot.
+#'   * [mcmc_parcoord()]: change the color/size/transparency of lines
+#'     corresponding to divergences.
+#'   * [mcmc_scatter()]: change the color/size/shape of points
+#'     corresponding to divergences.
+#'   * [mcmc_pairs()]: change the color/size/shape of points
+#'     corresponding divergences and/or max treedepth saturation.
 #'
 #' @examples
 #' \dontrun{
 #' library(ggplot2)
 #' library(rstanarm)
-#' fit <- stan_glm(mpg ~ wt + am, data = mtcars, iter = 1000)
+#' fit <- stan_glm(mpg ~ wt + am, data = mtcars, iter = 1000, refresh = 0)
 #' np <- nuts_params(fit)
 #' lp <- log_posterior(fit)
 #'
@@ -129,7 +117,7 @@
 #' mcmc_nuts_energy(np)
 #' mcmc_nuts_energy(np, merge_chains = TRUE, binwidth = .15)
 #' mcmc_nuts_energy(np) +
-#'  facet_wrap(~ Chain, nrow = 1) +
+#'  facet_wrap(vars(Chain), nrow = 1) +
 #'  coord_fixed(ratio = 150) +
 #'  ggtitle("NUTS Energy Diagnostic")
 #' }
@@ -146,7 +134,9 @@ mcmc_nuts_acceptance <-
            lp,
            chain = NULL,
            ...,
-           binwidth = NULL) {
+           binwidth = NULL,
+           bins = NULL,
+           breaks = NULL) {
     suggested_package("gridExtra")
     check_ignored_arguments(...)
 
@@ -165,24 +155,27 @@ mcmc_nuts_acceptance <-
                            Mean = mean(.data$Value),
                            Median = median(.data$Value))
 
-    hists <- ggplot(data, aes_(x = ~ Value, y = ~ ..density..)) +
+    hists <- ggplot(data, aes(x = .data$Value, y = after_stat(density))) +
       geom_histogram(
         fill = get_color("l"),
         color = get_color("lh"),
-        size = .25,
+        linewidth = 0.25,
         na.rm = TRUE,
-        binwidth = binwidth
-      )
+        binwidth = binwidth,
+        bins = bins,
+        breaks = breaks
+      ) +
+      bayesplot_theme_get()
 
     if (!overlay_chain) {
       hists <- hists +
         geom_vline(
-          aes_(xintercept = ~ Mean),
+          aes(xintercept = .data$Mean),
           data = stats_par,
           color = get_color("dh")
         ) +
         geom_vline(
-          aes_(xintercept = ~ Median),
+          aes(xintercept = .data$Median),
           data = stats_par,
           color = get_color("d"),
           linetype = 2
@@ -190,21 +183,26 @@ mcmc_nuts_acceptance <-
     }
     hists <- hists +
       dont_expand_y_axis(c(0.005, 0)) +
-      facet_wrap(~ Parameter, scales = "free") +
+      facet_wrap(vars(.data$Parameter), scales = "free") +
       yaxis_text(FALSE) +
       yaxis_title(FALSE) +
       yaxis_ticks(FALSE) +
       xaxis_title(FALSE)
 
-    scatter <- ggplot(NULL) +
+    scatter_data <- data.frame(
+      x = accept_stat$Value,
+      y = lp$Value
+    )
+    scatter <- ggplot(scatter_data) +
       geom_point(
-        aes_(x = ~ accept_stat$Value, y = ~ lp$Value),
+        aes(x = .data$x, y = .data$y),
         alpha = 0.75,
         shape = 21,
         fill = get_color(ifelse(overlay_chain, "l", "m")),
         color = get_color(ifelse(overlay_chain, "lh", "mh"))
       ) +
-      labs(x = "accept_stat__", y = "lp__")
+      labs(x = "accept_stat__", y = "lp__") +
+      bayesplot_theme_get()
 
     if (overlay_chain) {
       hists <- hists +
@@ -214,31 +212,24 @@ mcmc_nuts_acceptance <-
           color = NA,
           alpha = 0.5,
           na.rm = TRUE,
-          binwidth = binwidth
+          binwidth = binwidth,
+          bins = bins,
+          breaks = breaks
         )
 
+      chain_scatter_data <- data.frame(
+        x = accept_stat$Value[accept_stat$Chain == chain],
+        y = lp$Value[lp$Chain == chain]
+      )
       scatter <- scatter +
         geom_point(
-          aes_(x = ~ accept_stat$Value[accept_stat$Chain == chain],
-               y = ~ lp$Value[lp$Chain == chain]),
+          aes(x = .data$x, y = .data$y),
           color = get_color("d"),
-          alpha = 0.5
+          alpha = 0.5,
+          data = chain_scatter_data
         )
     }
-
-    nuts_plot <- gridExtra::arrangeGrob(
-      hists,
-      gridExtra::arrangeGrob(empty_grob()),
-      gridExtra::arrangeGrob(
-        empty_grob(),
-        scatter,
-        empty_grob(),
-        ncol = 3,
-        widths = c(1, 3, 1)
-      ),
-      nrow = 3,
-      heights = c(1, 0.1, 1)
-    )
+    nuts_plot <- gridExtra::arrangeGrob(hists, scatter, nrow = 2)
     as_bayesplot_grid(nuts_plot)
   }
 
@@ -259,17 +250,19 @@ mcmc_nuts_divergence <- function(x, lp, chain = NULL, ...) {
                             labels = c("No divergence", "Divergence"))
 
   violin_lp_data <- data.frame(divergent, lp = lp$Value)
-  violin_lp <- ggplot(violin_lp_data, aes_(x = ~ Value, y = ~ lp)) +
+  violin_lp <- ggplot(violin_lp_data, aes(x = .data$Value, y = .data$lp)) +
     geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("lp__") +
-    xaxis_title(FALSE)
+    xaxis_title(FALSE) +
+    bayesplot_theme_get()
 
   violin_accept_stat_data <- data.frame(divergent, as = accept_stat$Value)
-  violin_accept_stat <- ggplot(violin_accept_stat_data, aes_(x = ~ Value, y = ~ as)) +
+  violin_accept_stat <- ggplot(violin_accept_stat_data, aes(x = .data$Value, y = .data$as)) +
     geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("accept_stat__") +
     scale_y_continuous(limits = c(NA, 1.05)) +
-    xaxis_title(FALSE)
+    xaxis_title(FALSE) +
+    bayesplot_theme_get()
 
   div_count <- table(divergent$Value)[[2]]
   div_text <- ngettext(div_count, "divergence", "divergences")
@@ -319,21 +312,23 @@ mcmc_nuts_stepsize <- function(x, lp, chain = NULL, ...) {
   stepsize_labels <- scale_x_discrete(labels = stepsize_labels_text)
 
   violin_lp_data <- dplyr::left_join(lp, stepsize_by_chain, by = "Chain")
-  violin_lp <- ggplot(violin_lp_data, aes_(x = ~as.factor(ss), y = ~Value)) +
+  violin_lp <- ggplot(violin_lp_data, aes(x = as.factor(.data$ss), y = .data$Value)) +
     geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("lp__") +
     stepsize_labels +
-    xaxis_title(FALSE)
+    xaxis_title(FALSE) +
+    bayesplot_theme_get()
 
   violin_accept_stat_data <-
     dplyr::left_join(accept_stat, stepsize_by_chain, by = "Chain")
   violin_accept_stat <-
-    ggplot(violin_accept_stat_data, aes_(x = ~as.factor(ss), y = ~Value)) +
+    ggplot(violin_accept_stat_data, aes(x = as.factor(.data$ss), y = .data$Value)) +
     geom_violin(fill = get_color("l"), color = get_color("lh")) +
     ylab("accept_stat__") +
     scale_y_continuous(limits = c(NA, 1.05)) +
     stepsize_labels +
-    xaxis_title(FALSE)
+    xaxis_title(FALSE) +
+    bayesplot_theme_get()
 
   if (!is.null(chain)) {
     violin_lp <- violin_lp +
@@ -359,31 +354,34 @@ mcmc_nuts_treedepth <- function(x, lp, chain = NULL, ...) {
   treedepth <- dplyr::filter(x, .data$Parameter == "treedepth__")
   accept_stat <- dplyr::filter(x, .data$Parameter == "accept_stat__")
 
-  hist_td <- ggplot(treedepth, aes_(x = ~ Value, y = ~ ..density..)) +
+  hist_td <- ggplot(treedepth, aes(x = .data$Value, y = after_stat(density))) +
     geom_histogram(
       fill = get_color("l"),
       color = get_color("lh"),
-      size = .2,
+      linewidth = 0.2,
       na.rm = TRUE,
       binwidth = 1
     ) +
-    xlab("treedepth__") +
+    xlab("treedepth__")  +
+    bayesplot_theme_get() +
     yaxis_text(FALSE) +
     yaxis_title(FALSE) +
     yaxis_ticks(FALSE)
 
   violin_lp_data <- data.frame(treedepth, lp = lp$Value)
   violin_lp <-
-    ggplot(violin_lp_data, aes_(x = ~ factor(Value), y = ~ lp)) +
+    ggplot(violin_lp_data, aes(x = factor(.data$Value), y = .data$lp)) +
     geom_violin(fill = get_color("l"), color = get_color("lh")) +
-    labs(x = "treedepth__", y = "lp__")
+    labs(x = "treedepth__", y = "lp__") +
+    bayesplot_theme_get()
 
   violin_accept_stat_data <- data.frame(treedepth, as = accept_stat$Value)
   violin_accept_stat <-
-    ggplot(violin_accept_stat_data, aes_(x = ~ factor(Value), y = ~ as)) +
+    ggplot(violin_accept_stat_data, aes(x = factor(.data$Value), y = .data$as)) +
     geom_violin(fill = get_color("l"), color = get_color("lh")) +
     labs(x = "treedepth__", y = "accept_stat__") +
-    scale_y_continuous(breaks = c(0, 0.5, 1))
+    scale_y_continuous(breaks = c(0, 0.5, 1)) +
+    bayesplot_theme_get()
 
   if (overlay_chain) {
     hist_td <- hist_td +
@@ -403,19 +401,10 @@ mcmc_nuts_treedepth <- function(x, lp, chain = NULL, ...) {
       chain_violin(violin_accept_stat_data, chain)
   }
 
-  nuts_plot <- gridExtra::arrangeGrob(
-    gridExtra::arrangeGrob(
-      violin_lp, violin_accept_stat,
-      nrow = 1
-    ),
-    gridExtra::arrangeGrob(
-      empty_grob()
-    ),
-    gridExtra::arrangeGrob(
-      empty_grob(), hist_td, empty_grob(),
-      ncol = 3, widths = c(1, 3, 1)
-    ),
-    nrow = 3, heights = c(1, 0.1, 1)
+  nuts_plot <- gridExtra::grid.arrange(
+    gridExtra::arrangeGrob(violin_lp, violin_accept_stat, nrow = 1),
+    hist_td,
+    nrow = 2
   )
   as_bayesplot_grid(nuts_plot)
 }
@@ -423,16 +412,18 @@ mcmc_nuts_treedepth <- function(x, lp, chain = NULL, ...) {
 
 #' @rdname MCMC-nuts
 #' @export
-#' @param alpha For \code{mcmc_nuts_energy} only, the transparency (alpha) level
-#'   in [0,1] used for the overlaid histogram.
-#' @param merge_chains For \code{mcmc_nuts_energy} only, should all chains be
-#'   merged or displayed separately? The default is \code{FALSE}, i.e., to show
+#' @param alpha For `mcmc_nuts_energy()` only, the transparency (alpha) level
+#'   in `[0,1]` used for the overlaid histogram.
+#' @param merge_chains For `mcmc_nuts_energy()` only, should all chains be
+#'   merged or displayed separately? The default is `FALSE`, i.e., to show
 #'   the chains separately.
 #'
 mcmc_nuts_energy <-
   function(x,
            ...,
            binwidth = NULL,
+           bins = NULL,
+           breaks = NULL,
            alpha = 0.5,
            merge_chains = FALSE) {
     check_ignored_arguments(...)
@@ -446,40 +437,46 @@ mcmc_nuts_energy <-
       mutate(
         Ediff = .data$Value - dplyr::lag(.data$Value),
         E_centered = .data$Value - mean(.data$Value),
-        Ediff_centered = .data$Ediff - mean(.data$Ediff, na.rm = TRUE))
+        Ediff_centered = .data$Ediff - mean(.data$Ediff, na.rm = TRUE)
+      )
 
-    fills <- setNames(get_color(c("l", "m")), c("E_fill", "Ediff_fill"))
-    clrs <- setNames(get_color(c("lh", "mh")), c("E_fill", "Ediff_fill"))
+    fills <- set_names(get_color(c("l", "m")), c("E_fill", "Ediff_fill"))
+    clrs <- set_names(get_color(c("lh", "mh")), c("E_fill", "Ediff_fill"))
     aes_labs <- c(expression(pi[E]), expression(pi[paste(Delta, E)]))
 
-    graph <- ggplot(data, aes_(y = ~ ..density..)) +
+    graph <- ggplot(data, aes(y = after_stat(density))) +
       geom_histogram(
-        aes_(
-          x = ~ Ediff_centered,
-          fill = ~ "Ediff_fill",
-          color = ~ "Ediff_fill"
+        aes(
+          x = .data$Ediff_centered,
+          fill = "Ediff_fill",
+          color = "Ediff_fill"
         ),
-        size = 0.25,
+        linewidth = 0.25,
         na.rm = TRUE,
-        binwidth = binwidth
+        binwidth = binwidth,
+        bins = bins,
+        breaks = breaks
       ) +
       geom_histogram(
-        aes_(
-          x = ~ E_centered,
-          fill = ~ "E_fill",
-          color = ~ "E_fill"
+        aes(
+          x = .data$E_centered,
+          fill = "E_fill",
+          color = "E_fill"
         ),
-        size = 0.25,
+        linewidth = 0.25,
         na.rm = TRUE,
         alpha = alpha,
-        binwidth = binwidth
+        binwidth = binwidth,
+        bins = bins,
+        breaks = breaks
       ) +
       scale_fill_manual("", values = fills, labels = aes_labs) +
       scale_color_manual("", values = clrs, labels = aes_labs) +
       dont_expand_y_axis(c(0.005, 0)) +
       scale_x_continuous(expand = c(0.2, 0)) +
       labs(y = NULL, x = expression(E - bar(E))) +
-      space_legend_keys() +
+      bayesplot_theme_get() +
+      space_legend_keys()  +
       theme(legend.text = element_text(size = rel(1.1))) +
       yaxis_text(FALSE) +
       yaxis_title(FALSE) +
@@ -490,7 +487,7 @@ mcmc_nuts_energy <-
     }
 
     graph +
-      facet_wrap(~ Chain) +
+      facet_wrap(vars(.data$Chain)) +
       force_axes_in_facets()
   }
 
@@ -499,46 +496,53 @@ mcmc_nuts_energy <-
 validate_enough_chains <- function(chain = NULL, n_chain) {
   if (!is.null(chain)) {
     stopifnot(chain >= 1)
-    if (!isTRUE(n_chain >= chain))
-      stop("'chain' is ", chain, " but only ", n_chain, " chains found.")
+    if (!isTRUE(n_chain >= chain)) {
+      abort(paste("'chain' is", chain, "but only", n_chain, "chains found."))
+    }
   }
   chain
 }
 
 #' @param x data frame with nuts params
-#' @param lp data frame with lp__
+#' @param lp data frame with `lp__`
 #' @noRd
 validate_nuts_data_frame <- function(x, lp) {
-  if (!is.data.frame(x))
-    stop("NUTS parameters should be in a data frame.")
+  if (!is.data.frame(x)) {
+    abort("NUTS parameters should be in a data frame.")
+  }
 
-  valid_cols <- c("Iteration", "Parameter", "Value", "Chain")
-  if (!identical(colnames(x), valid_cols))
-    stop(
-      "NUTS parameter data frame must have columns: ",
+  valid_cols <- sort(c("Iteration", "Parameter", "Value", "Chain"))
+  if (!identical(sort(colnames(x)), valid_cols)) {
+    abort(paste(
+      "NUTS parameter data frame must have columns:",
       paste(valid_cols, collapse = ", ")
-    )
+    ))
+  }
 
-  if (missing(lp))
+  if (missing(lp)) {
     lp <- NULL
+  }
   if (!is.null(lp)) {
-    if (!is.data.frame(lp))
-      stop("lp should be in a data frame.")
+    if (!is.data.frame(lp)) {
+      abort("lp should be in a data frame.")
+    }
 
-    valid_lp_cols <- c("Iteration", "Value", "Chain")
-    if (!identical(colnames(lp), valid_lp_cols))
-      stop(
-        "lp data frame must have columns: ",
+    valid_lp_cols <- sort(c("Iteration", "Value", "Chain"))
+    if (!identical(sort(colnames(lp)), valid_lp_cols)) {
+      abort(paste(
+        "lp data frame must have columns:",
         paste(valid_lp_cols, collapse = ", ")
-      )
+      ))
+    }
 
     n_chain <- num_chains(x)
     n_lp_chain <- num_chains(lp)
-    if (n_chain != n_lp_chain)
-      stop(
-        "Number of chains for NUTS parameters is ", n_chain,
-        " but number of chains for lp is ", n_lp_chain, "."
-      )
+    if (n_chain != n_lp_chain) {
+      abort(paste(
+        "Number of chains for NUTS parameters is", n_chain,
+        "but number of chains for lp is", n_lp_chain
+      ))
+    }
   }
 
   x
@@ -557,7 +561,3 @@ chain_violin <-
       alpha = alpha
     )
   }
-
-empty_grob <- function() {
-  structure(list(), class = c("grob", "gDesc"))
-}
