@@ -1,6 +1,6 @@
-#' Trace plots of MCMC draws
+#' Trace and rank plots of MCMC draws
 #'
-#' Trace plot (or traceplot) of MCMC draws. See the **Plot Descriptions**
+#' Trace and rank plots of MCMC draws. See the **Plot Descriptions**
 #' section, below, for details.
 #'
 #' @name MCMC-traces
@@ -10,6 +10,7 @@
 #' @template args-regex_pars
 #' @template args-transformations
 #' @template args-facet_args
+#' @template args-pit-ecdf
 #' @param ... Currently ignored.
 #' @param size An optional value to override the default line size
 #'   for `mcmc_trace()` or the default point size for `mcmc_trace_highlight()`.
@@ -63,9 +64,18 @@
 #'    Ranks from `mcmc_rank_hist()` are plotted using overlaid lines in a
 #'    single panel.
 #'   }
+#'   \item{`mcmc_rank_ecdf()`}{
+#'    The ECDFs of the ranks from `mcmc_rank_hist()` are plotted with the
+#'    simultaneous confidence bands with a coverage determined by `prob`, that
+#'    is, bands that completely cover all of the rank ECDFs with the probability
+#'    `prob`. If `plot_diff = TRUE`, the difference between the observed rank
+#'    ECDFs and the theoretical expectation for samples originating from the
+#'    same distribution is drawn. See Säilynoja et al. (2021) for details.
+#'   }
 #' }
 #'
 #' @template reference-improved-rhat
+#' @template reference-uniformity-test
 #' @examples
 #' # some parameter draws to use for demonstration
 #' x <- example_mcmc_draws(chains = 4, params = 6)
@@ -105,6 +115,12 @@
 #' mcmc_rank_hist(x, pars = c("alpha", "sigma"), ref_line = TRUE)
 #' mcmc_rank_overlay(x, "alpha")
 #'
+#' # ECDF and ECDF difference plots of the ranking of MCMC samples between chains.
+#' # Provide 99% simultaneous confidence intervals for the chains sampling from
+#' # the same distribution.
+#' mcmc_rank_ecdf(x, prob = 0.99)
+#' mcmc_rank_ecdf(x, prob = 0.99, plot_diff = TRUE)
+#'
 #' \dontrun{
 #' # parse facet label text
 #' color_scheme_set("purple")
@@ -144,15 +160,6 @@
 #'   np = nuts_params(fit),
 #'   np_style = trace_style_np(div_color = "black", div_size = 0.5)
 #' )
-#'
-#' mcmc_trace(
-#'   posterior,
-#'   pars = c("wt", "sigma"),
-#'   size = 0.8,
-#'   facet_args = list(nrow = 2),
-#'   divergences = nuts_params(fit),
-#'   div_color = "black"
-#' )
 #' }
 #'
 NULL
@@ -275,6 +282,7 @@ mcmc_rank_overlay <- function(x,
                               pars = character(),
                               regex_pars = character(),
                               transformations = list(),
+                              facet_args = list(),
                               ...,
                               n_bins = 20,
                               ref_line = FALSE) {
@@ -287,6 +295,7 @@ mcmc_rank_overlay <- function(x,
   )
 
   n_chains <- unique(data$n_chains)
+  n_param <- unique(data$n_parameters)
 
   # We have to bin and count the data ourselves because
   # ggplot2::stat_bin(geom = "step") does not draw the final bin.
@@ -296,7 +305,7 @@ mcmc_rank_overlay <- function(x,
     group_by(.data$cut) %>%
     mutate(bin_start = min(.data$value_rank)) %>%
     ungroup() %>%
-    select(-.data$cut)
+    select(-c("cut"))
 
   d_bin_counts <- data %>%
     left_join(histobins, by = "value_rank") %>%
@@ -324,11 +333,18 @@ mcmc_rank_overlay <- function(x,
     NULL
   }
 
+  facet_call <- NULL
+  if (n_param > 1) {
+    facet_args$facets <- vars(.data$parameter)
+    facet_args$scales <- facet_args$scales %||% "fixed"
+    facet_call <- do.call("facet_wrap", facet_args)
+  }
+
   ggplot(d_bin_counts) +
-    aes_(x = ~ bin_start, y =  ~ n, color = ~ chain) +
+    aes(x = .data$bin_start, y =  .data$n, color = .data$chain) +
     geom_step() +
     layer_ref_line +
-    facet_wrap("parameter") +
+    facet_call +
     scale_color +
     ylim(c(0, NA)) +
     bayesplot_theme_get() +
@@ -371,14 +387,16 @@ mcmc_rank_hist <- function(x,
   right_edge <- max(data_boundaries$value_rank)
 
   facet_args[["scales"]] <- facet_args[["scales"]] %||% "fixed"
-  facet_args[["facets"]] <- facet_args[["facets"]] %||% (parameter ~ chain)
 
   # If there is one parameter, put the chains in one row.
   # Otherwise, use a grid.
   if (n_param > 1) {
     facet_f <- facet_grid
+    facet_args[["rows"]] <- facet_args[["rows"]] %||% vars(.data$parameter)
+    facet_args[["cols"]] <- facet_args[["cols"]] %||% vars(.data$chain)
   } else {
     facet_f <- facet_wrap
+    facet_args[["facets"]] <- vars(.data$parameter, .data$chain)
     facet_args[["nrow"]] <- facet_args[["nrow"]] %||% 1
     labeller <- function(x) label_value(x, multi_line = FALSE)
     facet_args[["labeller"]] <- facet_args[["labeller"]] %||% labeller
@@ -398,13 +416,13 @@ mcmc_rank_hist <- function(x,
   facet_call <- do.call(facet_f, facet_args)
 
   ggplot(data) +
-    aes_(x = ~ value_rank) +
+    aes(x = .data$value_rank) +
     geom_histogram(
       color = get_color("mid_highlight"),
       fill = get_color("mid"),
       binwidth = right_edge / n_bins,
       boundary = right_edge,
-      size = .25
+      linewidth = 0.25
     ) +
     layer_ref_line +
     geom_blank(data = data_boundaries) +
@@ -421,6 +439,112 @@ mcmc_rank_hist <- function(x,
     labs(x = "Rank")
 }
 
+#' @rdname MCMC-traces
+#' @param prob For `mcmc_rank_ecdf()`, a value between 0 and 1
+#' specifying the desired simultaneous confidence of the confidence bands to be
+#' drawn for the rank ECDF plots.
+#' @param plot_diff For `mcmc_rank_ecdf()`, a boolean specifying if the
+#' difference between the observed rank ECDFs and the theoretical expectation
+#' should be drawn instead of the unmodified rank ECDF plots.
+#' @export
+mcmc_rank_ecdf <-
+  function(x,
+           pars = character(),
+           regex_pars = character(),
+           transformations = list(),
+           ...,
+           K = NULL,
+           facet_args = list(),
+           prob = 0.99,
+           plot_diff = FALSE,
+           interpolate_adj = NULL) {
+  check_ignored_arguments(...,
+    ok_args = c("K", "pit", "prob", "plot_diff", "interpolate_adj", "M")
+  )
+  data <- mcmc_trace_data(
+    x,
+    pars = pars,
+    regex_pars = regex_pars,
+    transformations = transformations,
+    highlight = 1
+  )
+  n_iter <- unique(data$n_iterations)
+  n_chain <- unique(data$n_chains)
+  n_param <- unique(data$n_parameters)
+
+  x <- if (is.null(K)) {
+    0:n_iter / n_iter
+  } else {
+    0:K / K
+  }
+  gamma <- adjust_gamma(
+    N = n_iter,
+    L = n_chain,
+    K = if (is.null(K)) {
+      n_iter
+    } else {
+      K
+    },
+    prob = prob,
+    interpolate_adj = interpolate_adj,
+    ...
+  )
+  lims <- ecdf_intervals(
+    gamma = gamma,
+    N = n_iter,
+    K = if (is.null(K)) {
+      n_iter
+    } else {
+      K
+    },
+    L <- n_chain
+  )
+  data_lim <- data.frame(
+    upper = lims$upper / n_iter - (plot_diff == TRUE) * x,
+    lower = lims$lower / n_iter - (plot_diff == TRUE) * x,
+    x = x
+  )
+  data <- data %>%
+    group_by(.data$parameter, .data$chain) %>%
+    dplyr::group_map(~ data.frame(
+      parameter = .y[1],
+      chain = .y[2],
+      ecdf_value = ecdf(.x$value_rank / (n_iter * n_chain))(x) -
+        (plot_diff == TRUE) * x,
+      x = x
+    )) %>%
+    dplyr::bind_rows()
+
+  mapping <- aes(
+    x = .data$x,
+    y = .data$ecdf_value,
+    color = .data$chain,
+    group = .data$chain
+  )
+
+  scale_color <- scale_color_manual("Chain", values = chain_colors(n_chain))
+
+  facet_call <- NULL
+  if (n_param == 1) {
+    facet_call <- ylab(levels(data$parameter))
+  } else {
+    facet_args$facets <- vars(.data$parameter)
+    facet_args$scales <- facet_args$scales %||% "free"
+    facet_call <- do.call("facet_wrap", facet_args)
+  }
+
+  ggplot() +
+    geom_step(data = data_lim, aes(x = .data$x, y = .data$upper), show.legend = FALSE) +
+    geom_step(data = data_lim, aes(x = .data$x, y = .data$lower), show.legend = FALSE) +
+    geom_step(mapping, data) +
+    bayesplot_theme_get() +
+    scale_color +
+    facet_call +
+    scale_x_continuous(breaks = pretty) +
+    legend_move(ifelse(n_chain > 1, "right", "none")) +
+    xaxis_title(FALSE) +
+    yaxis_title(on = n_param == 1)
+}
 
 #' @rdname MCMC-traces
 #' @export
@@ -473,7 +597,7 @@ mcmc_trace_data <- function(x,
       value_rank = rank(.data$value, ties.method = "average")
     ) %>%
     ungroup() %>%
-    select(!!! first_cols, dplyr::everything())
+    select(!!! first_cols, tidyselect::everything())
 
   data$highlight <- if (!is.null(highlight)) {
     data$chain == highlight
@@ -517,23 +641,23 @@ mcmc_trace_data <- function(x,
   n_chain <- unique(data$n_chains)
   n_param <- unique(data$n_parameters)
 
-  mapping <- aes_(
-    x = ~ iteration,
-    y = ~ value,
-    color = ~ chain
+  mapping <- aes(
+    x = .data$iteration,
+    y = .data$value,
+    color = .data$chain
   )
 
   if (!is.null(highlight)) {
-    mapping <- modify_aes_(
+    mapping <- modify_aes(
       mapping,
-      alpha = ~ highlight,
-      color = ~ highlight
+      alpha = .data$highlight,
+      color = .data$highlight
     )
   }
 
   layer_warmup <- if (n_warmup > 0) {
     layer_warmup <- annotate(
-      "rect", xmin = -Inf, xmax = n_warmup, ymin = -Inf, ymax = Inf, size = 1,
+      "rect", xmin = -Inf, xmax = n_warmup, ymin = -Inf, ymax = Inf, linewidth = 1,
       color = "gray88", fill = "gray88", alpha = 0.5
     )
   } else {
@@ -541,7 +665,11 @@ mcmc_trace_data <- function(x,
   }
 
   geom_args <- list()
-  geom_args$size <- size %||% ifelse(style == "line", 1/3, 1)
+  if (style == "line") {
+    geom_args$linewidth = size %||% 1 / 3
+  } else {
+    geom_args$size = size %||% 1
+  }
   layer_draws <- do.call(paste0("geom_", style), geom_args)
 
   coord_window <- if (!is.null(window)) {
@@ -583,7 +711,7 @@ mcmc_trace_data <- function(x,
   if (n_param == 1) {
     facet_call <- ylab(levels(data$parameter))
   } else {
-    facet_args$facets <- ~ parameter
+    facet_args$facets <- vars(.data$parameter)
     facet_args$scales <- facet_args$scales %||% "free"
     facet_call <- do.call("facet_wrap", facet_args)
   }
@@ -604,7 +732,6 @@ mcmc_trace_data <- function(x,
     yaxis_title(on = n_param == 1)
 }
 
-
 chain_colors <- function(n) {
   all_clrs <- unlist(color_scheme_get())
   clrs <- switch(
@@ -671,13 +798,13 @@ divergence_rug <- function(np, np_style, n_iter, n_chain) {
   }
 
   geom_rug(
-    aes_(x = ~ Divergent, linetype = "Divergence"),
+    aes(x = .data$Divergent, linetype = "Divergence"),
     data = div_info,
     na.rm = TRUE,
     inherit.aes = FALSE,
     sides = "b",
     color = np_style$color[["div"]],
-    size = np_style$size[["div"]],
+    linewidth = np_style$size[["div"]],
     alpha = np_style$alpha[["div"]]
   )
 }
