@@ -362,6 +362,7 @@ ppc_hist <-
            yrep,
            ...,
            binwidth = NULL,
+           bins = NULL,
            breaks = NULL,
            freq = TRUE) {
     check_ignored_arguments(...)
@@ -375,6 +376,7 @@ ppc_hist <-
       geom_histogram(
         linewidth = 0.25,
         binwidth = binwidth,
+        bins = bins,
         breaks = breaks
       ) +
       scale_fill_ppc() +
@@ -400,6 +402,7 @@ ppc_freqpoly <-
            yrep,
            ...,
            binwidth = NULL,
+           bins = NULL,
            freq = TRUE,
            size = 0.5,
            alpha = 1) {
@@ -418,6 +421,7 @@ ppc_freqpoly <-
       geom_area(
         stat = "bin",
         binwidth = binwidth,
+        bins = bins,
         linewidth = size,
         alpha = alpha
       ) +
@@ -444,6 +448,7 @@ ppc_freqpoly_grouped <-
            group,
            ...,
            binwidth = NULL,
+           bins = NULL,
            freq = TRUE,
            size = 0.5,
            alpha = 1) {
@@ -601,13 +606,13 @@ ppc_pit_ecdf <- function(y,
   if (is.null(pit)) {
     pit <- ppc_data(y, yrep) %>%
       group_by(.data$y_id) %>%
-      dplyr::group_map(~ mean(.x$value[.x$is_y] >= .x$value[!.x$is_y])) %>%
+      dplyr::group_map(
+        ~ mean(.x$value[.x$is_y] > .x$value[!.x$is_y]) +
+        runif(1, max = mean(.x$value[.x$is_y] == .x$value[!.x$is_y]))
+        ) %>%
       unlist()
     if (is.null(K)) {
-      K <- min(
-        length(unique(ppc_data(y, yrep)$rep_id)) + 1,
-        length(pit)
-      )
+      K <- nrow(yrep) + 1
     }
   } else {
     inform("'pit' specified so ignoring 'y', and 'yrep' if specified.")
@@ -627,20 +632,22 @@ ppc_pit_ecdf <- function(y,
   ggplot() +
     aes(
       x = 1:K / K,
-      y = ecdf(pit)(seq(0, 1, length.out = K)) - (plot_diff == TRUE) * 1:K / K,
+      y = ecdf(pit)(seq(0, 1, length.out = K)) -
+          (plot_diff == TRUE) * seq(0, 1, length.out = K),
       color = "y"
     ) +
     geom_step(show.legend = FALSE) +
     geom_step(aes(
-      y = lims$upper[-1] / N - (plot_diff == TRUE) * 1:K / K,
+      y = lims$upper[-1] / N - (plot_diff == TRUE) * seq(0, 1, length.out = K),
       color = "yrep"
-    ), show.legend = FALSE) +
+    ),
+    linetype = 2, show.legend = FALSE) +
     geom_step(aes(
-      y = lims$lower[-1] / N - (plot_diff == TRUE) * 1:K / K,
+      y = lims$lower[-1] / N - (plot_diff == TRUE) * seq(0, 1, length.out = K),
       color = "yrep"
-    ), show.legend = FALSE) +
-    yaxis_title(FALSE) +
-    xaxis_title(FALSE) +
+    ),
+    linetype = 2, show.legend = FALSE) +
+    labs(y = ifelse(plot_diff,"ECDF - difference","ECDF"), x = "PIT") +
     yaxis_ticks(FALSE) +
     scale_color_ppc() +
     bayesplot_theme_get()
@@ -666,10 +673,13 @@ ppc_pit_ecdf_grouped <-
     if (is.null(pit)) {
       pit <- ppc_data(y, yrep, group) %>%
         group_by(.data$y_id) %>%
-        dplyr::group_map(~ mean(.x$value[.x$is_y] >= .x$value[!.x$is_y])) %>%
+        dplyr::group_map(
+          ~ mean(.x$value[.x$is_y] > .x$value[!.x$is_y]) +
+          runif(1, max = mean(.x$value[.x$is_y] == .x$value[!.x$is_y]))
+          ) %>%
         unlist()
       if (is.null(K)) {
-        K <- length(unique(ppc_data(y, yrep)$rep_id)) + 1
+        K <- nrow(yrep) + 1
       }
     } else {
       inform("'pit' specified so ignoring 'y' and 'yrep' if specified.")
@@ -718,13 +728,14 @@ ppc_pit_ecdf_grouped <-
       geom_step(aes(
         y = .data$lims_upper - (plot_diff == TRUE) * .data$x,
         color = "yrep"
-      ), show.legend = FALSE) +
+      ),
+      linetype = 2, show.legend = FALSE) +
       geom_step(aes(
         y = .data$lims_lower - (plot_diff == TRUE) * .data$x,
         color = "yrep"
-      ), show.legend = FALSE) +
-      xaxis_title(FALSE) +
-      yaxis_title(FALSE) +
+      ),
+      linetype = 2, show.legend = FALSE) +
+      labs(y = ifelse(plot_diff,"ECDF - difference","ECDF"), x = "PIT") +
       yaxis_ticks(FALSE) +
       bayesplot_theme_get() +
       facet_wrap("group") +
